@@ -791,7 +791,7 @@ if __name__ == '__main__':
         formatter_class=argparse.RawTextHelpFormatter)
 
     parser.add_argument(
-        '-i', '--input', metavar='input', default=None,
+        'input', metavar='input', default=None,
         help='The path to the optional image file for opening.')
     parser.add_argument(
         '-a', '--annotation', metavar='annotation', default=None,
